@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date :  October 2008
 # Version 0.9
 # Licence GPL v3
@@ -54,15 +54,16 @@ inMemory <- function(x) {
 	}
 }
 
-
-hasValues <- function(x) {
-	if (class(x) == 'BasicRaster') { return(FALSE) }
-	if (inherits(x, 'RasterStack')) { 
-		if (nlayers(x) > 0) return(TRUE) else return(FALSE)
+setMethod("hasValues", signature(x="BasicRaster"), 
+	function(x, ...) {
+		if (class(x) == 'BasicRaster') { return(FALSE) }
+		if (inherits(x, 'RasterStack')) { 
+			if (nlayers(x) > 0) return(TRUE) else return(FALSE)
+		}
+		if ( fromDisk(x)  | inMemory(x) ) {
+			return(TRUE)
+		} else {
+			return(FALSE)
+		}
 	}
-	if ( fromDisk(x)  | inMemory(x) ) {
-		return(TRUE)
-	} else {
-		return(FALSE)
-	}
-}
+)
