@@ -22,14 +22,16 @@ setMethod('quantile', signature(x='Raster'),
 			}
 		}
 		if (na.rm) {
-			v <- na.omit(v)
+			v <- stats::na.omit(v)
 		}
 		if (nlayers(x)==1) {
 			return(quantile(v, ...))
 		} else {
-			q <- quantile(v[,1], ...)
+			# t(apply(v, 2, quantile, na.rm=TRUE))
+
+			q <- stats::quantile(v[,1], ...)
 			for (i in 2:nlayers(x)) {
-				q <- rbind(q, quantile(v[,i], ...))
+				q <- rbind(q, stats::quantile(v[,i], ...))
 			}
 			rownames(q) <- names(x)
 			return(q)
